@@ -64,19 +64,8 @@ class SymbolsCommand(Command):
     def format_pyclass(symbols, desc_symbols, args):
         print_('class res:')
         if args.features:
-            print_("    def __getitem__(self, name):")
-            print_("        value = getattr(self, name)")
-            print_("        return value, c4d.plugins.GeLoadString(value)")
-            print_("    def __call__(self, name):")
-            print_("        return c4d.plugins.GeLoadString(getattr(self, name))")
-            print_("    def file(self, *parts):")
-            print_("        return os.path.join(os.path.dirname(__file__), 'res', *parts)")
-            print_("    def bitmap(self, *parts):")
-            print_("        bmp = c4d.bitmaps.BaseBitmap()")
-            print_("        res, ismovie = bmp.InitWith(self.file(*parts))")
-            print_("        if res != c4d.IMAGERESULT_OK: return None")
-            print_("        return bmp")
-            print_()
+            with open(os.path.join(PKGRES, 'sym-pyclass-head_py')) as fp:
+                print_(fp.read())
 
         for line in SymbolsCommand.preprocess_pyvars(symbols):
             print_('    ', line, sep='')
@@ -89,6 +78,18 @@ class SymbolsCommand(Command):
             print_("    pass")
         print_("res = res()")
 
+    @staticmethod
+    def format_pyfile(symbols, desc_symbols, args):
+        if args.features:
+            with open(os.path.join(PKGRES, 'sym-pyfile-head_py')) as fp:
+                print_(fp.read())
+        for line in SymbolsCommand.preprocess_pyvars(symbols):
+            print_(line)
+        if symbols and desc_symbols:
+            print_()
+        for line in SymbolsCommand.preprocess_pyvars(desc_symbols):
+            print_(line)
+
     @staticmethod
     def preprocess_pyvars(symbols):
         if not symbols: return
@@ -105,7 +106,7 @@ class SymbolsCommand(Command):
         parser.add_argument(
             'format',
             help='The output format of the extracted symbols.',
-            choices=['json', 'pyclass', 'pydict'])
+            choices=['json', 'pyclass', 'pydict', 'pyfile'])
         parser.add_argument(
             'plugdir', nargs='?', default=None,
             help='The plugin directory that contains a res/ directory. '
@@ -147,7 +148,7 @@ class BootstrapCommand(Command):
             help='The output file. Outputs to stdout if not specified')
 
     def execute(self, args):
-        with open(os.path.join(PKGRES, 'bootstrap.pyp.data')) as fp:
+        with open(os.path.join(PKGRES, 'bootstrap_pyp')) as fp:
             data = fp.read()
         if args.output is not None:
             with open(args.output, 'wb') as fp:
